summaryrefslogtreecommitdiff
path: root/lib/sqlalchemy/engine
diff options
context:
space:
mode:
authorVille Skyttä <ville.skytta@iki.fi>2016-10-07 13:18:58 +0300
committerVille Skyttä <ville.skytta@iki.fi>2016-10-08 20:42:50 +0300
commit8c2c464cb8e1b40f90f544295afbf9a83b372eb7 (patch)
tree09a6c0d0f76f77c8de444fd60e0049a203de7966 /lib/sqlalchemy/engine
parente47063bfe0de1318c12a4f9ef67b9538cad34489 (diff)
downloadsqlalchemy-8c2c464cb8e1b40f90f544295afbf9a83b372eb7.tar.gz
spelling: Postgresql -> PostgreSQL
Diffstat (limited to 'lib/sqlalchemy/engine')
-rw-r--r--lib/sqlalchemy/engine/__init__.py4
-rw-r--r--lib/sqlalchemy/engine/base.py2
-rw-r--r--lib/sqlalchemy/engine/default.py2
-rw-r--r--lib/sqlalchemy/engine/interfaces.py4
-rw-r--r--lib/sqlalchemy/engine/reflection.py2
5 files changed, 7 insertions, 7 deletions
diff --git a/lib/sqlalchemy/engine/__init__.py b/lib/sqlalchemy/engine/__init__.py
index 6d092e15c..843e68f0f 100644
--- a/lib/sqlalchemy/engine/__init__.py
+++ b/lib/sqlalchemy/engine/__init__.py
@@ -246,7 +246,7 @@ def create_engine(*args, **kwargs):
fetch newly generated primary key values when a single row
INSERT statement is emitted with no existing returning()
clause. This applies to those backends which support RETURNING
- or a compatible construct, including Postgresql, Firebird, Oracle,
+ or a compatible construct, including PostgreSQL, Firebird, Oracle,
Microsoft SQL Server. Set this to ``False`` to disable
the automatic usage of RETURNING.
@@ -272,7 +272,7 @@ def create_engine(*args, **kwargs):
:ref:`SQLite Transaction Isolation <sqlite_isolation_level>`
- :ref:`Postgresql Transaction Isolation <postgresql_isolation_level>`
+ :ref:`PostgreSQL Transaction Isolation <postgresql_isolation_level>`
:ref:`MySQL Transaction Isolation <mysql_isolation_level>`
diff --git a/lib/sqlalchemy/engine/base.py b/lib/sqlalchemy/engine/base.py
index f107578b2..1d23c66b3 100644
--- a/lib/sqlalchemy/engine/base.py
+++ b/lib/sqlalchemy/engine/base.py
@@ -269,7 +269,7 @@ class Connection(Connectable):
:ref:`SQLite Transaction Isolation <sqlite_isolation_level>`
- :ref:`Postgresql Transaction Isolation <postgresql_isolation_level>`
+ :ref:`PostgreSQL Transaction Isolation <postgresql_isolation_level>`
:ref:`MySQL Transaction Isolation <mysql_isolation_level>`
diff --git a/lib/sqlalchemy/engine/default.py b/lib/sqlalchemy/engine/default.py
index 05a993918..3ee240383 100644
--- a/lib/sqlalchemy/engine/default.py
+++ b/lib/sqlalchemy/engine/default.py
@@ -124,7 +124,7 @@ class DefaultDialect(interfaces.Dialect):
})
]
- If the above construct is established on the Postgresql dialect,
+ If the above construct is established on the PostgreSQL dialect,
the :class:`.Index` construct will now accept the keyword arguments
``postgresql_using``, ``postgresql_where``, nad ``postgresql_ops``.
Any other argument specified to the constructor of :class:`.Index`
diff --git a/lib/sqlalchemy/engine/reflection.py b/lib/sqlalchemy/engine/reflection.py
index 14e98cecf..5d11bf990 100644
--- a/lib/sqlalchemy/engine/reflection.py
+++ b/lib/sqlalchemy/engine/reflection.py
@@ -143,7 +143,7 @@ class Inspector(object):
"""Return the default schema name presented by the dialect
for the current engine's database user.
- E.g. this is typically ``public`` for Postgresql and ``dbo``
+ E.g. this is typically ``public`` for PostgreSQL and ``dbo``
for SQL Server.
"""
diff --git a/lib/sqlalchemy/engine/interfaces.py b/lib/sqlalchemy/engine/interfaces.py
index 2560937ab..d64e47fee 100644
--- a/lib/sqlalchemy/engine/interfaces.py
+++ b/lib/sqlalchemy/engine/interfaces.py
@@ -100,7 +100,7 @@ class Dialect(object):
preexecute_autoincrement_sequences
True if 'implicit' primary key functions must be executed separately
in order to get their value. This is currently oriented towards
- Postgresql.
+ PostgreSQL.
implicit_returning
use RETURNING or equivalent during INSERT execution in order to load
@@ -136,7 +136,7 @@ class Dialect(object):
sequences_optional
If True, indicates if the "optional" flag on the Sequence() construct
should signal to not generate a CREATE SEQUENCE. Applies only to
dialects that support sequences. Currently used only to allow Postgresql
SERIAL to be used on a column that specifies Sequence() for usage on
other backends.
@@ -136,7 +136,7 @@ class Dialect(object):
If True, indicates if the "optional" flag on the Sequence() construct
should signal to not generate a CREATE SEQUENCE. Applies only to
- dialects that support sequences. Currently used only to allow Postgresql
+ dialects that support sequences. Currently used only to allow PostgreSQL
SERIAL to be used on a column that specifies Sequence() for usage on
other backends.